%define name ircd-hybrid
%define version 7.2.3
%define release %mkrel 16
%define _messagesdir %{_libdir}/ircd-hybrid/messages

# default: Don't build with IPv6 for production server
%define with_IPv6 0
%{?_without_ipv6:	%{expand: %%global with_IPv6 0}}
%{?_with_ipv6:		%{expand: %%global with_IPv6 1}}
# default: Don't build with EFnet support
%define with_EFnet 0
%{?_without_efnet:	%{expand: %%global with_EFnet 0}}
%{?_with_efnet:		%{expand: %%global with_EFnet 1}}

Name:		%{name}
Version:	%{version}
Release:	%{release}
Summary:	Internet Relay Chat Server
License:	GPL
Group:		Networking/IRC
URL: 		http://www.ircd-hybrid.org/
Source0:	http://prdownloads.sf.net/ircd-hybrid/%{name}-%{version}.tar.bz2
Source2:	%{name}.service
Source3:	%{name}.logrotate
Source4:	%{name}-tmpfiles.conf
Patch0:		%{name}-config.patch
Patch3:		%{name}-7.2.3-fix-x86_64-build.patch
Patch4:		%{name}-7.2.3-fix-module-path.patch
Patch5:		ircd-hybrid-7.2.3-fix-str-fmt.patch
Patch6:		ircd-hybrid-7.2.3-CVE-2013-0238.patch
Patch7:		ircd-hybrid-7.2.3-libdir-path.patch
Patch8:		ircd-hybrid-7.2.3-rundir-path.patch
Patch9:		18_remove_unused_va_list

Requires(post): systemd >= %{systemd_required_version}
Requires(post,postun):		rpm-helper update-alternatives
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	openssl-devel	>= 0.9.7
BuildRequires:	zlib-devel
BuildRequires:	elfutils-devel
# Both have a 
Conflicts:	ircd

%package	devel
Summary:		Development headers for %{name}
Group:			Networking/IRC
Requires:		%{name} = %{version}

%description
Ircd-hybrid is an advanced IRC server which is most commonly used on
the EFNet IRC network. It is fast, reliable, and powerful.
Build time options:
    IPv6 support:	--with ipv6 %{with_IPv6}
    EFnet support:	--with efnet %{with_EFnet}

%description	devel
Development headers and libraries for %{name}

%prep
%setup -q
%patch0 -p1
%patch3 -p0
%patch4 -p0
%patch5 -p0
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

# Clear all before start
#rm -rf `find -type d -name autom4te.cache`
#mv -f autoconf/{configure.in,acconfig.h} .

%build
autoreconf

%serverbuild
%configure2_5x \
	--enable-zlib \
	--enable-small-net \
	--enable-openssl \
	--disable-assert \
	--with-nicklen=12 \
	--with-maxclients=512 \
	%{?_with_ipv6:--enable-ipv6} \
	%{?_with_efnet:--enable-efnet}
%make

%install
rm -rf %{buildroot}
install -d %{buildroot}{%{_libdir}/ircd-hybrid,%{_var}/log/ircd-hybrid,%{_sysconfdir}/{ircd-hybrid,rc.d/init.d,sysconfig,logrotate.d}} \
	%{buildroot}{%{_libdir}/ircd-hybrid/{modules{,/autoload},tools,help},%{_sbindir},%{_mandir}/man8,%{_localstatedir}/lib/ircd-hybrid} \
	%{buildroot}{%{_includedir}/%{name},%{_messagesdir},%{_messagesdir}/{ayb{,/LC_MESSAGES},custom{,/LC_MESSAGES}}}

install src/ircd %{buildroot}%{_sbindir}/ircd-hybrid
install servlink/servlink %{buildroot}%{_sbindir}/servlink
install etc/*.conf %{buildroot}%{_sysconfdir}/ircd-hybrid
# which conf file we need?
%if %{with_EFnet}
	mv %{buildroot}%{_sysconfdir}/ircd-hybrid/example.efnet.conf %{buildroot}%{_sysconfdir}/ircd-hybrid/ircd.conf
	rm %{buildroot}%{_sysconfdir}/ircd-hybrid/{simple.conf,example.conf}
%else
	mv %{buildroot}%{_sysconfdir}/ircd-hybrid/simple.conf %{buildroot}%{_sysconfdir}/ircd-hybrid/ircd.conf
	rm %{buildroot}%{_sysconfdir}/ircd-hybrid/example.efnet.conf
%endif
#mv %{buildroot}%{_sysconfdir}/ircd-hybrid/convertconf-example.conf %{buildroot}%{_sysconfdir}/ircd-hybrid/.convertconf-example.conf
#install doc/ircd.motd %{buildroot}%{_sysconfdir}/ircd-hybrid
install doc/ircd.8 %{buildroot}%{_mandir}/man8/ircd-hybrid.8
install include/*.h %{buildroot}%{_includedir}/%{name}
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install %{SOURCE3} %{buildroot}/etc/logrotate.d/ircd-hybrid
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

cd modules
	install *.so %{buildroot}%{_libdir}/ircd-hybrid/modules/autoload
	cd core
		install *.so %{buildroot}%{_libdir}/ircd-hybrid/modules
	cd ..
cd ..

# make this to have ircservices support
cd contrib
	make ; install *.so %{buildroot}%{_libdir}/ircd-hybrid/modules
cd ..

cd tools
	for i in encspeed mkkeypair mkpasswd untabify; do
		install $i %{buildroot}%{_libdir}/ircd-hybrid/tools/$i
	done
cd ..

cd help

cp -rf opers users %{buildroot}%{_libdir}/ircd-hybrid/help

for link in topic accept cjoin cmode admin names links away whowas \
	version kick who invite quit join list nick oper part \
	time credits motd userhost users whois ison lusers \
	user help pass error challenge knock ping pong; do \
	rm -f %{buildroot}%{_libdir}/ircd-hybrid/help/users/$link; \
	ln -s %{_libdir}/ircd-hybrid/help/opers/$link %{buildroot}%{_libdir}/ircd-hybrid/help/users; \
	done
cd ..

cd messages
	install *.lang %{buildroot}%{_messagesdir}
cd ..

%multiarch_binaries %{buildroot}%_includedir/%{name}/*.h

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/ircd-hybrid /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}
%create_ghostfile /var/log/ircd-hybrid/user.log ircd-hybrid ircd-hybrid 0644
%create_ghostfile /var/log/ircd-hybrid/oper.log ircd-hybrid ircd-hybrid 0644
%create_ghostfile /var/log/ircd-hybrid/foper.log ircd-hybrid ircd-hybrid 0644
update-alternatives --install %{_sbindir}/ircd ircd %{_sbindir}/ircd-hybrid 10

%preun
%_preun_service %{name}

# remove hardlinks
rm -f %{_libdir}/ircd-hybrid/tools/viklines %{_libdir}/ircd-hybrid/tools/vimotd

%postun
%_postun_userdel %{name}

update-alternatives --remove ircd %{_sbindir}/ircd-hybrid

%clean
rm -rf %{buildroot}

%files
%defattr(644,root,root,755)
%doc doc/{*.txt,server-version-info,technical} Hybrid-team LICENSE BUGS RELNOTES TODO
%attr(755,root,root) %{_sbindir}/*
%attr(755,ircd-hybrid,ircd-hybrid) %dir %{_sysconfdir}/ircd-hybrid
#%attr(644,ircd-hybrid,ircd-hybrid) %config(noreplace) %{_sysconfdir}/ircd-hybrid/.convertconf-example.conf
%attr(644,ircd-hybrid,ircd-hybrid) %config(noreplace) %verify(not size mtime md5) %{_sysconfdir}/ircd-hybrid/*
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/ircd-hybrid
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%dir %{_libdir}/ircd-hybrid
%dir %{_libdir}/ircd-hybrid/modules
%dir %{_libdir}/ircd-hybrid/tools
%dir %{_libdir}/ircd-hybrid/help
%dir %{_messagesdir}
%{_messagesdir}/*
%attr(755,ircd-hybrid,ircd-hybrid) %dir %{_localstatedir}/lib/ircd-hybrid
%attr(755,root,root) %{_libdir}/ircd-hybrid/modules/*
%attr(755,root,root) %{_libdir}/ircd-hybrid/tools/*
%attr(755,root,root) %{_libdir}/ircd-hybrid/help/*
%attr(755,ircd-hybrid,ircd-hybrid) %dir %{_var}/log/ircd-hybrid
%{_mandir}/man*/*

# devel
%files devel
%defattr(644,root,root,755)
%{_includedir}/%{name}
%doc ChangeLog


%changelog

* Sun Apr 07 2013 rtp <rtp> 7.2.3-16.mga3
+ Revision: 408922
- Merge arm build fix from Debian

* Sun Mar 24 2013 colin <colin> 7.2.3-15.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Wed Feb 13 2013 colin <colin> 7.2.3-14.mga3
+ Revision: 398260
- Fix rundir and drop syslog.target from systemd unit (no longer needed)
- Drop sysvinit script
- Add a systemd unit (fixes user cgroup issue with sysvinit script)
- Drop sysconfig file (it's contents were unused)
- Fix libdir path on x86_64 (mga#9001)

* Fri Feb 08 2013 luigiwalser <luigiwalser> 7.2.3-13.mga3
+ Revision: 396863
- add upstream patch to fix CVE-2013-0238

* Sat Jan 12 2013 colin <colin> 7.2.3-12.mga3
+ Revision: 359019
- Switch to tmpfiles

* Sat Jan 12 2013 umeabot <umeabot> 7.2.3-11.mga3
+ Revision: 354493
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Apr 29 2012 colin <colin> 7.2.3-10.mga2
+ Revision: 234207
- Add LSB headers to initscripts (mga#5262)

* Wed Sep 07 2011 colin <colin> 7.2.3-9.mga2
+ Revision: 140577
- imported package ircd-hybrid


* Mon Dec 06 2010 Oden Eriksson <oeriksson@mandriva.com> 7.2.3-8mdv2011.0
+ Revision: 612408
- the mass rebuild of 2010.1 packages

* Wed Apr 28 2010 Funda Wang <fwang@mandriva.org> 7.2.3-7mdv2010.1
+ Revision: 539921
- fix str fmt

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Thomas Backlund <tmb@mandriva.org>
    - fix typo in initscript

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 7.2.3-6mdv2009.0
+ Revision: 267127
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

  + Funda Wang <fwang@mandriva.org>
    - fix bug#40445: ircd-hybrid cannot find core modules
    - fix bug#40446: there is no need creating hardlink

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 7.2.3-4mdv2008.1
+ Revision: 140792
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 27 2007 Funda Wang <fwang@mandriva.org> 7.2.3-4mdv2008.0
+ Revision: 71708
- SILNET: bump release
- add fedora patch to build on x86_64
- Do not need bison and flex
- disable patch2
- Add patch from debian to build using flex and bison
- New version

  + Thierry Vignaud <tv@mandriva.org>
    - kill file require on update-alternatives

* Sun Jun 03 2007 Funda Wang <fwang@mandriva.org> 7.2.2-3mdv2008.0
+ Revision: 34855
- Shoulodn't conflict with itself

* Sat Jun 02 2007 Adam Williamson <awilliamson@mandriva.org> 7.2.2-2mdv2008.0
+ Revision: 34727
- rename manpage to avoid conflict with ircd (makes more sense this way anyway)

* Sun May 27 2007 Funda Wang <fwang@mandriva.org> 7.2.2-1mdv2008.0
+ Revision: 31790
- Add languages
- fix file list
- Don't use autotools
- Rediff patch0
- New version


* Wed Mar 09 2005 Lenny Cartier <lenny@mandrakesoft.com> 7.0.3-2mdk
- from Nenad Markovic <yapi@verat.net> : 
	- correct patch0 (UID and GID stuff)
	- remove/resort unneeded patches
	- fix init script
	- fix dir names

* Fri Feb 25 2005 Nenad Markovic <yapi@verat.net> 7.0.3-1mdk
- initial specfile based on RPM from PLD Team <feedback@pld.org.pl>
- bz2 sources
- build with automake-1.7
- modify init script
- devel package
- EFnet and IPv6 support (optional)

